Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6739)

Unified Diff: chrome/browser/ui/website_settings/permission_prompt.h

Issue 2182883002: Permissions: Rename PermissionBubbleView to PermissionPromptInterface (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: thestig@ review Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/website_settings/permission_bubble_view.h ('k') | chrome/chrome_browser_ui.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/website_settings/permission_prompt.h
diff --git a/chrome/browser/ui/website_settings/permission_bubble_view.h b/chrome/browser/ui/website_settings/permission_prompt.h
similarity index 63%
rename from chrome/browser/ui/website_settings/permission_bubble_view.h
rename to chrome/browser/ui/website_settings/permission_prompt.h
index 2beeacbbde2ddbc2151ebba1691dcf3e84e3d3db..7e23677186c5172f1fd1ccefbbe3e7af8f0908ce 100644
--- a/chrome/browser/ui/website_settings/permission_bubble_view.h
+++ b/chrome/browser/ui/website_settings/permission_prompt.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_BUBBLE_VIEW_H_
-#define CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_BUBBLE_VIEW_H_
+#ifndef CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_PROMPT_H_
+#define CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_PROMPT_H_
#include <memory>
#include <vector>
@@ -16,10 +16,10 @@ class PermissionRequestManager;
class PermissionRequest;
// This class is the platform-independent interface through which the permission
-// bubble managers (which are one per tab) communicate to the UI surface.
+// request managers (which are one per tab) communicate to the UI surface.
// When the visible tab changes, the UI code must provide an object of this type
// to the manager for the visible tab.
-class PermissionBubbleView {
+class PermissionPrompt {
public:
// The delegate will receive events caused by user action which need to
// be persisted in the per-tab UI state.
@@ -33,43 +33,41 @@ class PermissionBubbleView {
virtual void Closing() = 0;
};
- typedef base::Callback<std::unique_ptr<PermissionBubbleView>(Browser*)>
- Factory;
+ typedef base::Callback<std::unique_ptr<PermissionPrompt>(Browser*)> Factory;
// Create a platform specific instance.
- static std::unique_ptr<PermissionBubbleView> Create(Browser* browser);
- virtual ~PermissionBubbleView() {}
+ static std::unique_ptr<PermissionPrompt> Create(Browser* browser);
+ virtual ~PermissionPrompt() {}
- // Sets the delegate which will receive UI events forwarded from the bubble.
+ // Sets the delegate which will receive UI events forwarded from the prompt.
virtual void SetDelegate(Delegate* delegate) = 0;
- // Causes the bubble to show up with the given contents. This method may be
- // called with mostly-identical contents to the existing contents. This can
+ // Causes the request UI to show up with the given contents. This method may
+ // be called with mostly-identical contents to the existing contents. This can
// happen, for instance, if a new permission is requested and
// CanAcceptRequestUpdate() is true.
// Important: the view must not store any of the request objects it receives
// in this call.
- virtual void Show(
- const std::vector<PermissionRequest*>& requests,
- const std::vector<bool>& accept_state) = 0;
+ virtual void Show(const std::vector<PermissionRequest*>& requests,
+ const std::vector<bool>& accept_state) = 0;
// Returns true if the view can accept a new Show() command to coalesce
// requests. Currently the policy is that this should return true if the view
// is being shown and the mouse is not over the view area (!IsMouseHovered).
virtual bool CanAcceptRequestUpdate() = 0;
// Hides the permission bubble.
virtual void Hide() = 0;
// Returns true if there is a bubble currently showing.
virtual bool IsVisible() = 0;
// Updates where the bubble should be anchored. ex: fullscreen toggle.
virtual void UpdateAnchorPosition() = 0;
// Returns a reference to this bubble's native window.
// TODO(hcarmona): Remove this as part of the bubble API work.
virtual gfx::NativeWindow GetNativeWindow() = 0;
};
-#endif // CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_BUBBLE_VIEW_H_
+#endif // CHROME_BROWSER_UI_WEBSITE_SETTINGS_PERMISSION_PROMPT_H_
« no previous file with comments | « chrome/browser/ui/website_settings/permission_bubble_view.h ('k') | chrome/chrome_browser_ui.gypi » ('j') | no next file with comments »

Powered by Google App Engine
@@ -33,43 +33,41 @@ class PermissionBubbleView {
// is being shown and the mouse is not over the view area (!IsMouseHovered).
virtual bool CanAcceptRequestUpdate() = 0;
- // Hides the permission bubble.
+ // Hides the permission prompt.
virtual void Hide() = 0;
@@ -33,43 +33,41 @@ class PermissionBubbleView {
virtual void Hide() = 0;
- // Returns true if there is a bubble currently showing.
+ // Returns true if there is a prompt currently showing.
virtual bool IsVisible() = 0;
@@ -33,43 +33,41 @@ class PermissionBubbleView {
virtual bool IsVisible() = 0;
- // Updates where the bubble should be anchored. ex: fullscreen toggle.
+ // Updates where the prompt should be anchored. ex: fullscreen toggle.
virtual void UpdateAnchorPosition() = 0;
@@ -33,43 +33,41 @@ class PermissionBubbleView {
virtual void UpdateAnchorPosition() = 0;
- // Returns a reference to this bubble's native window.
+ // Returns a reference to this prompt's native window.
// TODO(hcarmona): Remove this as part of the bubble API work.
virtual gfx::NativeWindow GetNativeWindow() = 0;
This is Rietveld 408576698